==> mysql-community_8.4.0.orig.tar.gz: mysql-8.4.0/storage/ndb/clusterj/clusterj-core/src/main/java/com/mysql/clusterj/core/store/ClusterConnection.java <==
/*
 *  Copyright (c) 2010, 2024, Oracle and/or its affiliates.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2.0,
 *  as published by the Free Software Foundation.
 *
 *  This program is designed to work with certain software (including
 *  but not limited to OpenSSL) that is licensed under separate terms,
 *  as designated in a particular file or component or in included license
 *  documentation.  The authors of MySQL hereby grant you an additional
 *  permission to link the program and your derivative works with the
 *  separately licensed software that they have either included with
 *  the program or referenced in the documentation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License, version 2.0, for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

package com.mysql.clusterj.core.store;

import com.mysql.clusterj.core.spi.ValueHandlerFactory;

/**
 *
 */
public interface ClusterConnection {

    public void connect(int connectRetries, int connectDelay, boolean verbose);

    public Db createDb(String database, int maxTransactions);

    public void configureTls(String searchPath, int requirement);

    public void waitUntilReady(int connectTimeoutBefore, int connectTimeoutAfter);

    public void closing();

    public void close();

    public int dbCount();

    public void close(Db db);

    public void unloadSchema(String tableName);

    public ValueHandlerFactory getSmartValueHandlerFactory();

    public void initializeAutoIncrement(long[] autoIncrement);

    public void setByteBufferPoolSizes(int[] poolSizes);

    public void setRecvThreadCPUid(short cpuid);

    public void unsetRecvThreadCPUid();

    public void setRecvThreadActivationThreshold(int threshold);
}

==> mysql-community_9.5.0.orig.tar.gz: mysql-9.5.0/storage/ndb/clusterj/clusterj-core/src/main/java/com/mysql/clusterj/core/store/ClusterConnection.java <==
/*
 *  Copyright (c) 2010, 2025, Oracle and/or its affiliates.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2.0,
 *  as published by the Free Software Foundation.
 *
 *  This program is designed to work with certain software (including
 *  but not limited to OpenSSL) that is licensed under separate terms,
 *  as designated in a particular file or component or in included license
 *  documentation.  The authors of MySQL hereby grant you an additional
 *  permission to link the program and your derivative works with the
 *  separately licensed software that they have either included with
 *  the program or referenced in the documentation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License, version 2.0, for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

package com.mysql.clusterj.core.store;

import com.mysql.clusterj.core.spi.ValueHandlerFactory;

/**
 *
 */
public interface ClusterConnection {

    public void connect(int connectRetries, int connectDelay, boolean verbose);

    public void configureTls(String searchPath, int requirement);

    public void waitUntilReady(int connectTimeoutBefore, int connectTimeoutAfter);

    public void close();

    public int nodeId();

    public String systemName();

    public ValueHandlerFactory getSmartValueHandlerFactory();

    public void initializeAutoIncrement(long[] autoIncrement);

    public void setRecvThreadCPUid(short cpuid);

    public void unsetRecvThreadCPUid();

    public short getRecvThreadCPUid();

    public void setRecvThreadActivationThreshold(int threshold);

    DbFactory createDbFactory(String databaseName, int[] bufferSizes);
}
